<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Jul 12, 2021
 */

/**
 * @package InterWorx
 * @subpackage
 */
class Model_ApiResponse_Backup
{
    const API_CREATED = 'created';
    const API_BACKUP_ID = 'backup_id';
    const API_LEGACY_ID = 'legacy_id';
    const API_TENANT_ID = 'tenant_id';
    const API_ARCHIVE = 'archive';
    const API_VAULT_ID = 'vault_id';
    const API_ARCHIVE_ID = 'id';
    const API_AGENT_ID = 'agent_id';

    private $_created;
    private $_date;
    private $_backupId;
    private $_legacyId;
    private $_vaultId;
    private $_archiveId;
    private $_machineId;
    private $_tenantId;

    /**
     * @param array $apiResponse
     */
    public function __construct(array $apiResponse)
    {
        $this->_created = $apiResponse[self::API_CREATED];
        $this->_date = Model_Acronis::formatDate($this->_created);

        $this->_backupId = $apiResponse[self::API_BACKUP_ID];
        $this->_legacyId = $apiResponse[self::API_LEGACY_ID];
        $this->_tenantId = $apiResponse[self::API_TENANT_ID];

        $archive = $apiResponse[self::API_ARCHIVE];
        $this->_vaultId = $archive[self::API_VAULT_ID];
        $this->_archiveId = $archive[self::API_ARCHIVE_ID];
        $this->_machineId = $archive[self::API_AGENT_ID];
    }

    /**
     * @return integer
     */
    public function getTimeStamp()
    {
        return strtotime($this->_created);
    }

    /**
     * @return string
     */
    public function getBackupId()
    {
        return $this->_backupId;
    }

    /**
     * Get api backup details as array.
     *
     * @return array
     */
    public function toArray()
    {
        return array(
            Model_Backups_Backup::DATE => $this->_date,
            Model_Backups_Backup::BACKUP_ID => $this->_backupId,
            Model_Backups_Backup::LEGACY_ID => $this->_legacyId,
            Model_Backups_Backup::VAULT_ID => $this->_vaultId,
            Model_Backups_Backup::ARCHIVE_ID => $this->_archiveId,
            Model_Backups_Backup::MACHINE_ID => $this->_machineId,
            Model_Backups_Backup::CREATED => $this->_created,
            Model_Backups_Backup::TENANT_AGENT_ID => $this->_tenantId
        );
    }
}
