<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2022 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Jul 01, 2022
 */

class Model_Resources_ResourceMachine
{
    private $_id;
    private $_agent_id;
    private $_name;
    private $_agent_details;

    /**
     * @param array $api_res
     */
    public function __construct(array $api_res)
    {
        $this->_id = $api_res['id'];
        $this->_agent_id = $api_res['agent_id'];
        $this->_name = $api_res['name'];
        $this->_agent_details = $this->_getAgentDetails($api_res);
    }

    /**
     * @param array $api_res
     */
    private function _getAgentDetails(array $api_res): array
    {
        $attributes = $api_res['attributes'];
        $key_value_sets = $this->_getAgentKvsFromAttributes($attributes);

        $details = array();

        foreach ($key_value_sets as $set) {
            $key = $set['key'];
            $value = $set['value'];
            $details[$key] = $value;
        }

        return $details;
    }

    /**
     * @param array $attributes
     */
    private function _getAgentKvsFromAttributes(array $attributes): array
    {
        foreach ($attributes as $attr) {
            if ($attr['name'] === 'agent') {
                return $attr['kvs'];
            }
        }
    }

    /**
     * @return string
     */
    public function getInstanceId(): string
    {
        return $this->_id;
    }

    /**
     * @return string
     */
    public function getAgentId(): string
    {
        return $this->_agent_id;
    }

    /**
     * Should be same as hostname
     *
     * @return string
     */
    public function getName(): string
    {
        return $this->_name;
    }

    /**
     * Might be useful in troubleshooting or future implementation.
     *
     * Includes:
     *
     * components
     * features
     * os_family
     * os_name
     * os_arch
     * os_family
     * os_caps
     * os_product_type
     * os_service_pack
     * os_suite_mask
     * sku
     * os_version_major
     * os_version_minor
     * mac_addresses
     * memory_size
     * processor_frequency
     * processor_name
     * chassis
     * vm_host_type
     * esx_address
     * residental_addresses
     * inside_virtual
     * tz_offset
     * version
     * enabled
     * is_online
     *
     * @return array
     */
    public function getAgentDetails(): array
    {
        return $this->_agent_details;
    }
}
