<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Jun 16, 2021
 */
require_once(__DIR__ . './../../../Model/Cache/Restore/Files.php');

/**
 * @package InterWorx
 * @subpackage TESTS
 */
class Cache_FileRestoresTest extends IWorx_Framework_TestCase
{
    private $_SUT;

    private $_planId = 'somerandomplanid';
    private $_unixuser = 'someunixuser';
    private $_dirs = array(
        '/dir/one',
        '/dir/two',
    );

    /**
     * Create SUT & add to cache
     */
    public function setUp()
    {
        $this->_SUT = new Model_Cache_Restore_Files();
        $this->_time = Model_Acronis::getDateString(time());

        $data = array(
            $this->_SUT::TIME => $this->_time,
            $this->_SUT::DIRECTORIES => $this->_dirs,
            $this->_SUT::PLAN_ID => $this->_planId,
            $this->_SUT::UNIXUSER => $this->_unixuser,
        );


        $this->_SUT->add($this->_planId, $data);
    }

    /**
     * Delete test item from cache
     */
    public function tearDown()
    {
        $this->_getSut()->delete($this->_planId);
    }

    /**
     *
     */
    public function testGetByUser()
    {
        $SUT = $this->_getSut();

        $userRestores = $SUT->getByUser($this->_unixuser);
        $restore = $userRestores[0];

        $this->assertCount(1, $userRestores);
        $this->assertSame($restore[$SUT::DIRECTORIES], $this->_dirs);
        $this->assertSame($restore[$SUT::TIME], $this->_time);
        $this->assertSame($restore[$SUT::PLAN_ID], $this->_planId);
        $this->assertSame($restore[$SUT::UNIXUSER], $this->_unixuser);
    }

    /**
     * @return Model_Cache_Restore_Files
     */
    private function _getSut()
    {
        return $this->_SUT;
    }
}
